@@ -33,7 +33,7 @@ def get_embeddings_for_tokens(dataset, cdb, context_type='medium', special_token
                 if tkn in cdb.cui2names:
                     token_type = 'cui'
                     # Take the first type_id (should always be the most important one if there are more)
-                    token_type_detailed = list(cdb.cui2type_ids.get(cui, ['unk']))[0]
+                    token_type_detailed = list(cdb.cui2type_ids.get(tkn, ['unk']))[0]
 
                 if tkn in cdb.cui2context_vectors and context_type in cdb.cui2context_vectors[tkn]:
                     vec = cdb.cui2context_vectors[tkn][context_type]
