@@ -46,7 +46,11 @@ def precision(predictions, label_ids, id2tkn, id2type, token_types={'cui'}, pred
             For each label ID a count of negative examples
     '''
     if predictions_are_scores:
-        outputs = np.argsort(-1 * predictions, axis=2)
+        if type(predictions) == list:
+            outputs = [np.argsort(-1 * x, axis=1) for x in predictions]
+        else:
+            # TODO: do some validation here, as this will let any type of predictions through
+            outputs = np.argsort(-1 * predictions, axis=2)
     else:
         outputs = predictions
 
@@ -142,7 +146,13 @@ class ComputePrecisionHF(object):
             label_ids = p.label_ids[start:start+self.batch_size]
             if self.topk == 1:
                 # For speed do not send predictions as scores
-                predictions = np.argmax(predictions, axis=2)
+                if type(predictions) == list:
+                    # One by one
+                    predictions = [np.argmax(x, axis=1) for x in predictions]
+                else:
+                    # TODO: do some validation here, as this will let any type of predictions through
+                    predictions = np.argmax(predictions, axis=2)
+
             metrics_data = precision(predictions, label_ids=label_ids, id2tkn=self.id2tkn, id2type=self.id2type, old_data=metrics_data,
                                      predictions_are_scores=self.topk!=1, topk=self.topk, **self.kwargs)
             start += self.batch_size
